pub enum TransactionEvent<'t> {
Deferred(Hash, &'static str),
Dropped(Hash, &'static str),
Removed(Hash),
Included(&'t LedgerTransaction),
Executed(&'t SpentTransaction),
}Expand description
Represents events related to transactions.
-
Deferred(Hash, &'static str)Indicates that a transaction has been staged outside the real mempool and is waiting on an admission precondition such as a missing intermediate nonce. The
Hashidentifies the staged transaction and the string carries a compact reason. -
Dropped(Hash, &'static str)Indicates that a transaction has been discarded before entering the real mempool. The
Hashidentifies the dropped transaction and the string carries a compact reason. -
Removed(Hash)Indicates that a transaction has been removed from the mempool. The
Hashrepresents the unique identifier of the removed transaction.This event is triggered when a transaction is removed from the mempool or discarded from the mempool.
-
Included(&'t LedgerTransaction)A transaction has been included in the mempool.
-
Executed(&'t SpentTransaction)Denotes that a transaction has been executed into an accepted block. Executed transactions also include failed transaction, as they have been spent and were correctly executed according to any contract logic. (including logic that triggers panics)
- A “successful” transaction: executed and the
errfield isNone. - A “failed” transaction: executed and the
errfield isSome.
- A “successful” transaction: executed and the
Variants
Deferred(Hash, &'static str)
Dropped(Hash, &'static str)
Removed(Hash)
Included(&'t LedgerTransaction)
Executed(&'t SpentTransaction)