Module hard_fork

Module hard_fork 

Enums

HardFork
Active protocol hardfork.

Functions

bls_version_at
Returns the BLS version for the given block height.
hard_fork_at
Returns the active hardfork for block_height.
ingress_tx_format_at
Returns the ingress transaction format for the target block height.
ledger_tx_format_at
Returns the ledger transaction format for block_height.
set_aegis_activation_height
Initializes the Aegis activation height once for this process.
set_boreas_activation_height
Initializes the Boreas activation height once for this process.