pub fn ingress_tx_format_at(block_height: u64) -> TransactionFormatExpand description
Returns the ingress transaction format for the target block height.
pub fn ingress_tx_format_at(block_height: u64) -> TransactionFormatReturns the ingress transaction format for the target block height.