pub struct LedgerTransaction {
pub version: u32,
pub type: u32,
/* private fields */
}Expand description
Ledger transaction wrapper around a CanonicalTransaction.
Fields
version: u32type: u32Implementations
Sourceimpl LedgerTransaction
impl LedgerTransaction
pub fn decode_for_ingress( bytes: &[u8], block_height: u64, ) -> Result<Self, Error>
pub fn decode_for_ledger(bytes: &[u8], block_height: u64) -> Result<Self, Error>
pub fn decode_any(bytes: &[u8]) -> Result<Self, Error>
Sourcepub fn from_protocol_with_format(
protocol: ProtocolTransaction,
format: TransactionFormat,
) -> Self
pub fn from_protocol_with_format( protocol: ProtocolTransaction, format: TransactionFormat, ) -> Self
Builds a ledger transaction from a native protocol transaction and an explicit format.
pub fn from_protocol_for_ledger( protocol: ProtocolTransaction, block_height: u64, ) -> Self
pub fn from_protocol_for_ingress( protocol: ProtocolTransaction, block_height: u64, ) -> Self
Sourcepub fn reformat_for_ledger(&self, block_height: u64) -> Self
pub fn reformat_for_ledger(&self, block_height: u64) -> Self
Reformats a ledger transaction to the ledger format active at
block_height.
Sourcepub fn reformat_for_ingress(&self, block_height: u64) -> Self
pub fn reformat_for_ingress(&self, block_height: u64) -> Self
Reformats a ledger transaction to the ingress format active at
block_height.
pub fn format(&self) -> TransactionFormat
pub fn canonical(&self) -> &CanonicalTransaction
pub fn protocol(&self) -> &ProtocolTransaction
pub fn protocol_bytes(&self) -> Vec<u8> ⓘ
Sourcepub fn digest(&self) -> [u8; 32]
pub fn digest(&self) -> [u8; 32]
Computes the hash digest of the entire transaction data.
This method returns the Sha3 256 digest of the entire transaction in its serialized form. If the transaction is a blob transaction, the sidecar is stripped
The digest hash is currently only being used in the merkle tree.
Returns
An array of 32 bytes representing the hash of the transaction.
Sourcepub fn id(&self) -> [u8; 32]
pub fn id(&self) -> [u8; 32]
Computes the transaction ID.
The transaction ID is a unique identifier for the transaction.
Unlike the digest() method, which is computed over
the entire transaction, the transaction ID is derived from specific
fields of the transaction and serves as a unique identifier of the
transaction itself.
Returns
An array of 32 bytes representing the transaction ID.
pub fn gas_price(&self) -> u64
pub fn to_spend_ids(&self) -> Vec<SpendingId>
pub fn next_spending_id(&self) -> Option<SpendingId>
pub fn blob_mut(&mut self) -> Option<&mut Vec<BlobData>>
pub fn strip_blobs(&mut self) -> Option<Vec<([u8; 32], BlobSidecar)>>