Enums
- Hard
Fork - Active protocol hardfork.
Functions
- bls_
version_ at - Returns the BLS version for the given block height.
- hard_
fork_ at - Returns the active hardfork for
block_height. - ingress_
tx_ format_ at - Returns the ingress transaction format for the target block height.
- ledger_
tx_ format_ at - Returns the ledger transaction format for
block_height. - set_
aegis_ activation_ height - Initializes the Aegis activation height once for this process.
- set_
boreas_ activation_ height - Initializes the Boreas activation height once for this process.